@@ -92,7 +92,8 @@ enum
 	PROP_NAME,
 	PROP_STATE,
 	PROP_AUTO_SAVE,
-	PROP_AUTO_SAVE_INTERVAL
+	PROP_AUTO_SAVE_INTERVAL,
+	PROP_CAN_CLOSE
 };
 
 /* Signals */
@@ -206,6 +207,10 @@ gedit_tab_get_property (GObject    *object,
 			g_value_set_int (value,
 					 gedit_tab_get_auto_save_interval (tab));
 			break;
+		case PROP_CAN_CLOSE:
+			g_value_set_boolean (value,
+					     _gedit_tab_get_can_close (tab));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;			
@@ -339,6 +344,15 @@ gedit_tab_class_init (GeditTabClass *klass)
 							   G_PARAM_READWRITE |
 							   G_PARAM_STATIC_STRINGS));
 
+	g_object_class_install_property (object_class,
+					 PROP_CAN_CLOSE,
+					 g_param_spec_boolean ("can-close",
+							       "Can close",
+							       "Whether the tab can be closed",
+							       TRUE,
+							       G_PARAM_READABLE |
+							       G_PARAM_STATIC_STRINGS));
+
 	signals[DROP_URIS] =
 		g_signal_new ("drop-uris",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -477,6 +491,7 @@ gedit_tab_set_state (GeditTab      *tab,
 				       state);
 
 	g_object_notify (G_OBJECT (tab), "state");
+	g_object_notify (G_OBJECT (tab), "can-close");
 }
 
 static void 
@@ -506,6 +521,7 @@ document_modified_changed (GtkTextBuffer *document,
 			   GeditTab      *tab)
 {
 	g_object_notify (G_OBJECT (tab), "name");
+	g_object_notify (G_OBJECT (tab), "can-close");
 }
 
 static void
@@ -1089,7 +1105,7 @@ document_loaded (GeditDocument *document,
 			GList *all_documents;
 			GList *l;
 
-			all_documents = gedit_app_get_documents (gedit_app_get_default ());
+			all_documents = gedit_app_get_documents (GEDIT_APP (g_application_get_default ()));
 
 			for (l = all_documents; l != NULL; l = g_list_next (l))
 			{
@@ -1652,8 +1668,10 @@ gedit_tab_init (GeditTab *tab)
 					    GEDIT_SETTINGS_AUTO_SAVE);
 	g_settings_get (tab->priv->editor, GEDIT_SETTINGS_AUTO_SAVE_INTERVAL,
 			"u", &auto_save_interval);
-	
-	lockdown = gedit_app_get_lockdown (gedit_app_get_default ());
+
+	GeditApp *app = GEDIT_APP (g_application_get_default ());
+
+	lockdown = gedit_app_get_lockdown (app);
 	tab->priv->auto_save = auto_save &&
 			       !(lockdown & GEDIT_LOCKDOWN_SAVE_TO_DISK);
 	tab->priv->auto_save = (tab->priv->auto_save != FALSE);
@@ -2202,7 +2220,6 @@ _gedit_tab_load_stream (GeditTab            *tab,
 	                            encoding,
 	                            line_pos,
 	                            column_pos);
-
 }
 
 void
@@ -2429,7 +2446,7 @@ get_page_setup (GeditTab *tab)
 
 	if (data == NULL)
 	{
-		return _gedit_app_get_default_page_setup (gedit_app_get_default());
+		return _gedit_app_get_default_page_setup (GEDIT_APP (g_application_get_default ()));
 	}
 	else
 	{
@@ -2452,7 +2469,7 @@ get_print_settings (GeditTab *tab)
 
 	if (data == NULL)
 	{
-		settings = _gedit_app_get_default_print_settings (gedit_app_get_default());
+		settings = _gedit_app_get_default_print_settings (GEDIT_APP (g_application_get_default ()));
 	}
 	else
 	{
@@ -2508,7 +2525,7 @@ store_print_settings (GeditTab      *tab,
 				(GDestroyNotify)g_object_unref);
 
 	/* make them the default */
-	_gedit_app_set_default_print_settings (gedit_app_get_default (),
+	_gedit_app_set_default_print_settings (GEDIT_APP (g_application_get_default ()),
 					       settings);
 
 	page_setup = gedit_print_job_get_page_setup (job);
@@ -2520,7 +2537,7 @@ store_print_settings (GeditTab      *tab,
 				(GDestroyNotify)g_object_unref);
 
 	/* make it the default */
-	_gedit_app_set_default_page_setup (gedit_app_get_default (),
+	_gedit_app_set_default_page_setup (GEDIT_APP (g_application_get_default ()),
 					   page_setup);
 }
 
@@ -2823,7 +2840,7 @@ _gedit_tab_mark_for_closing (GeditTab *tab)
 }
 
 gboolean
-_gedit_tab_can_close (GeditTab *tab)
+_gedit_tab_get_can_close (GeditTab *tab)
 {
 	GeditDocument *doc;
 	GeditTabState  ts;
@@ -2843,15 +2860,25 @@ _gedit_tab_can_close (GeditTab *tab)
 
 	/* Do not close tab with saving errors */
 	if (ts == GEDIT_TAB_STATE_SAVING_ERROR)
+	{
 		return FALSE;
-		
+	}
+
 	doc = gedit_tab_get_document (tab);
 
-	/* TODO: we need to save the file also if it has been externally
-	   modified - Paolo (Oct 10, 2005) */
+	if (gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)))
+	{
+		return FALSE;
+	}
 
-	return (!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)) &&
-		!gedit_document_get_deleted (doc));
+	if (gedit_document_is_local (doc) &&
+	    (gedit_document_get_deleted (doc) ||
+	    _gedit_document_check_externally_modified (doc)))
+	{
+		return FALSE;
+	}
+
+	return TRUE;
 }
 
 /**
@@ -2892,9 +2919,11 @@ gedit_tab_set_auto_save_enabled	(GeditTab *tab,
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 
 	/* Force disabling when lockdown is active */
-	lockdown = gedit_app_get_lockdown (gedit_app_get_default());
+	lockdown = gedit_app_get_lockdown (GEDIT_APP (g_application_get_default ()));
 	if (lockdown & GEDIT_LOCKDOWN_SAVE_TO_DISK)
+	{
 		enable = FALSE;
+	}
 	
 	doc = gedit_tab_get_document (tab);
 
