@@ -205,13 +205,9 @@ hide_search_widget (GeditViewFrame *frame,
 static gboolean
 search_entry_flush_timeout (GeditViewFrame *frame)
 {
-	GDK_THREADS_ENTER ();
-
 	frame->priv->typeselect_flush_timeout = 0;
 	hide_search_widget (frame, FALSE);
 
-	GDK_THREADS_LEAVE ();
-
 	return FALSE;
 }
 
@@ -578,12 +574,8 @@ real_search_enable_popdown (gpointer data)
 {
 	GeditViewFrame *frame = GEDIT_VIEW_FRAME (data);
 
-	GDK_THREADS_ENTER ();
-
 	frame->priv->disable_popdown = FALSE;
 
-	GDK_THREADS_LEAVE ();
-
 	return FALSE;
 }
 
@@ -1015,7 +1007,7 @@ get_selected_text (GtkTextBuffer *doc, gchar **selected_text, gint *len)
 	if (!gtk_text_buffer_get_selection_bounds (doc, &start, &end))
 	{
 		if (len != NULL)
-			len = 0;
+			*len = 0;
 
 		return FALSE;
 	}
