@@ -93,7 +93,6 @@ struct _GeditWindowPrivate
 	GtkActionGroup *documents_list_action_group;
 	guint           documents_list_menu_ui_id;
 	GtkWidget      *toolbar;
-	GtkWidget      *toolbar_recent_menu;
 	GtkWidget      *menubar;
 
 	/* recent files */
@@ -114,6 +113,8 @@ struct _GeditWindowPrivate
 
 	GeditWindowState state;
 
+	guint           inhibition_cookie;
+
 	gint            bottom_panel_item_removed_handler_id;
 
 	GtkWindowGroup *window_group;
