@@ -238,7 +238,7 @@ on_response_cb (GtkWidget              *infobar,
 		GError *error = NULL;
 
 #ifdef OS_OSX
-		gedit_app_osx_show_url (GEDIT_APP_OSX (gedit_app_get_default ()),
+		gedit_app_osx_show_url (GEDIT_APP_OSX (g_application_get_default ()),
 		                        plugin->priv->url);
 #else
 		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (plugin->priv->window)),
